Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(413)

Unified Diff: third_party/WebKit/public/web/WebLocalFrame.h

Issue 1774663002: Teach CRFO:CapturePageText to recognize page refreshes with long delays. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed nits. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/web/WebLocalFrameImpl.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebLocalFrame.h
diff --git a/third_party/WebKit/public/web/WebLocalFrame.h b/third_party/WebKit/public/web/WebLocalFrame.h
index dae559c1b15b0cd0730ff03bd1a0ad4f5cea50c2..2d0eeb2537b49bddb0045f679802a91c31a45fa1 100644
--- a/third_party/WebKit/public/web/WebLocalFrame.h
+++ b/third_party/WebKit/public/web/WebLocalFrame.h
@@ -133,8 +133,8 @@ public:
// instead.
virtual bool isResourceLoadInProgress() const = 0;
// Returns true if there is a pending redirect or location change.
// This could be caused by:
// * an HTTP Refresh header
// * an X-Frame-Options header
// * the respective http-equiv meta tags
@@ -142,7 +142,7 @@ public:
// * CSP policy block
// * reload
// * form submission
- virtual bool isNavigationScheduled() const = 0;
+ virtual bool isNavigationScheduledWithin(double intervalInSeconds) const = 0;
// Override the normal rules for whether a load has successfully committed
// in this frame. Used to propagate state when this frame has navigated
« no previous file with comments | « third_party/WebKit/Source/web/WebLocalFrameImpl.cpp ('k') | no next file » | no next file with comments »
@@ -133,8 +133,8 @@ public:
// instead.
virtual bool isResourceLoadInProgress() const = 0;
- // Returns true if there is a pending redirect or location change.
- // This could be caused by:
+ // Returns true if there is a pending redirect or location change
+ // within specified interval (in seconds). This could be caused by:
// * an HTTP Refresh header
// * an X-Frame-Options header

Powered by Google App Engine
This is Rietveld 408576698